@@ -1,7 +1,7 @@
 try:
-    from django.conf.urls import *
+    from django.conf.urls import patterns, url
 except:
-    from django.conf.urls.defaults import *
+    from django.conf.urls.defaults import patterns, url
 
 
 urlpatterns = patterns('',
