@@ -1,7 +1,7 @@
 try:
-    from django.conf.urls import *
+    from django.conf.urls import patterns, url, include
 except:
-    from django.conf.urls.defaults import *
+    from django.conf.urls.defaults import patterns, url, include
 from django.conf.urls.static import static
 from django.contrib import admin
 from django.conf import settings
@@ -11,7 +11,9 @@ from ajax_select import urls as ajax_select_urls
 admin.autodiscover()
 
 urlpatterns = patterns('',
-    url(r'^search_form',  view='example.views.search_form', name='search_form'),
+    url(r'^search_form',
+        view='example.views.search_form',
+        name='search_form'),
     (r'^admin/lookups/', include(ajax_select_urls)),
     (r'^admin/', include(admin.site.urls)),
 ) + static(settings.STATIC_URL, document_root=settings.STATIC_ROOT)
